%global pkg proofgeneral

Name:           emacs-common-%{pkg}
Version:        4.2
Release:        5%{?dist}
Summary:        Emacs mode for standard interaction interface for proof assistants 

Group:          Applications/Editors
License:        GPLv2
URL:            http://proofgeneral.inf.ed.ac.uk/
Source0:        http://proofgeneral.inf.ed.ac.uk/releases/ProofGeneral-%{version}.tgz
Source1:        http://proofgeneral.inf.ed.ac.uk/ProofGeneralPortrait.eps.gz
Source2:        %{pkg}.appdata.xml

# Patch 0 - Fedora specific, don't do an "install-info" in the make process
# (which would occur at build time), but instead put it into a scriptlet
Patch0:         pg-4.2-Makefile.patch

# Bring the desktop file up to date with current standards.
Patch1:         pg-4.2-desktop.patch

# Adapt to texinfo 5.x
Patch2:         pg-4.2-texinfo.patch

BuildArch:      noarch
BuildRequires:  desktop-file-utils
BuildRequires:  emacs
BuildRequires:  emacs-el
BuildRequires:  tex-cm-super
BuildRequires:  tex-ec
BuildRequires:  tex-epstopdf
BuildRequires:  texinfo-tex

%description
Proof General is a generic front-end for proof assistants (also known
as interactive theorem provers) based on Emacs.

Proof General allows one to edit and submit a proof script to a proof
assistant in an interactive manner:
- It tracks the goal state, and the script as it is submitted, and
  allows for easy backtracking and block execution.
- It adds toolbars and menus to Emacs for easy access to proof
  assistant features.
- It integrates with Emacs Unicode support for some provers to provide
  output using proper mathematical symbols.
- It includes utilities for generating Emacs tags for proof scripts,
  allowing for easy navigation.

Proof General supports a number of different proof assistants
(Isabelle, Coq, PhoX, and LEGO to name a few) and is designed to be
easily extendable to work with others.

%package -n emacs-%{pkg}
Summary:        Compiled elisp files to run Proof General under GNU Emacs
Group:          Applications/Editors
Requires:       emacs(bin) >= %{_emacs_version}
Requires:       emacs-common-%{pkg} = %{version}-%{release}
# MMM Mode is separately packaged for emacs
Requires:       emacs-mmm

%description -n emacs-%{pkg}
Proof General is a generic front-end for proof assistants based on Emacs.

This package contains the byte compiled elisp packages to run Proof
General with GNU Emacs.

%package -n emacs-%{pkg}-el
Summary:        Elisp source files for Proof General under GNU Emacs
Group:          Applications/Editors
Requires:       emacs-%{pkg} = %{version}-%{release}

%description -n emacs-%{pkg}-el
This package contains the elisp source files for Proof General under
GNU Emacs. You do not need to install this package to run Proof
General. Install the emacs-%{pkg} package to use Proof General with
GNU Emacs.

%prep
%setup -q -n ProofGeneral-%{version}
%patch0
%patch1
%patch2

# Prepare the documentation image, and make the texi files use the right name
mkdir web
cp -p %{SOURCE1} web
cd doc
zcat ProofGeneralPortrait.eps.gz | epstopdf -f -o=ProofGeneralPortrait.pdf
cd ..
sed -i "s/image{ProofGeneral}/image{ProofGeneralPortrait}/" doc/*.texi

# See http://proofgeneral.inf.ed.ac.uk/trac/ticket/458
# It should be possible to remove this once ProofGeneral 4.3 is released.
sed -i 's/ (setq byte-compile-error-on-warn t)//' Makefile

%build
# Fix rpmlint complaints:

# Correct permissions for isartags script
chmod 755 isar/isartags
# Remove .cvsignore files
find . -name .cvsignore | xargs rm -f

# Fix non UTF-8 documentation and theory files
for f in phox/square-root-2.phx; do
  mv $f $f.old
  iconv -f iso-8859-1 -t utf8 $f.old > $f
  touch -r $f.old $f
  rm $f.old
done

# Make full copies of emacs versions, set options in the proofgeneral start
# script
make clean
make EMACS=emacs compile bashscripts perlscripts doc
sed -r -e 's|^EMACS_LISPDIR=.*$|EMACS_LISPDIR=%{_emacs_sitelispdir}|' \
    -e 's|^PACKAGE=.*$|PACKAGE=%{pkg}|' \
    -e 's|^(PGHOMEDEFAULT=).*|\1%{_emacs_sitelispdir}/%{pkg}|' \
    bin/proofgeneral > .tmp
touch -r bin/proofgeneral .tmp
mv -f .tmp bin/proofgeneral
mkdir emacs
for f in `find . -maxdepth 1 -mindepth 1 ! -name emacs`; do
  cp -pr $f emacs/$f
done

%install
%define full_doc_dir %{_datadir}/doc/%{pkg}
%define full_man_dir %{_mandir}/man1

%define doc_options DOCDIR=%{buildroot}%{full_doc_dir} MANDIR=%{buildroot}%{full_man_dir} INFODIR=%{buildroot}%{_infodir}
%define common_options PREFIX=%{buildroot}%{_prefix} DEST_PREFIX=%{_prefix} DESKTOP=%{buildroot}%{_datadir} BINDIR=%{buildroot}%{_bindir} %{doc_options}

%define emacs_options ELISP_START=%{buildroot}%{_emacs_sitestartdir} ELISP=%{buildroot}%{_emacs_sitelispdir}/%{pkg} DEST_ELISP=%{_emacs_sitelispdir}/%{pkg}

cp -pr `find emacs/ -maxdepth 1 -mindepth 1` .
make EMACS=emacs %{common_options} %{emacs_options} install install-doc

# Don't accidentally install an infodir file over an existing one
rm -f %{buildroot}%{_infodir}/dir

# Remove empty, obsolete directories
rmdir %{buildroot}%{full_doc_dir}/lclam %{buildroot}%{full_doc_dir}/plastic

# Fix executable bits on scripts
chmod a+x %{buildroot}%{_bindir}/*

# Validate the desktop file
desktop-file-validate %{buildroot}%{_datadir}/applications/proofgeneral.desktop

# Install the AppData file
mkdir -p %{buildroot}%{_datadir}/appdata
install -pm 644 %{SOURCE2} %{buildroot}%{_datadir}/appdata

%post
/sbin/install-info %{_infodir}/ProofGeneral.info* %{_infodir}/dir 2>/dev/null || :
/sbin/install-info %{_infodir}/PG-adapting.info* %{_infodir}/dir 2>/dev/null || :
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%preun
if [ $1 -eq 0 ]; then
  /sbin/install-info --delete %{_infodir}/ProofGeneral.info* %{_infodir}/dir 2>/dev/null || :
  /sbin/install-info --delete %{_infodir}/PG-adapting.info* %{_infodir}/dir 2>/dev/null || :
fi

%postun
if [ $1 -eq 0 ] ; then
  /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
  /usr/bin/gtk-update-icon-cache -f %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache -f %{_datadir}/icons/hicolor &>/dev/null || :

%files
%{full_doc_dir}
%{full_man_dir}/*
%{_infodir}/*
%{_bindir}/*
%{_datadir}/appdata/%{pkg}.appdata.xml
%{_datadir}/application-registry/%{pkg}.applications
%{_datadir}/applications/%{pkg}.desktop
%{_datadir}/icons/hicolor/*/%{pkg}.png
%{_datadir}/mime-info/%{pkg}.*
%{_datadir}/pixmaps/%{pkg}.png

%files -n emacs-%{pkg}
%{_emacs_sitelispdir}/%{pkg}/*
# Exclude bundled mmm-mode, packaged separately
%exclude %{_emacs_sitelispdir}/%{pkg}/contrib
%exclude %{_emacs_sitelispdir}/%{pkg}/*/*.el
%{_emacs_sitestartdir}/*.el
%dir %{_emacs_sitelispdir}/%{pkg}

%files -n emacs-%{pkg}-el
%{_emacs_sitelispdir}/%{pkg}/*/*.el

%changelog
* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 4.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Feb 27 2014 Jerry James <loganjerry@gmail.com> - 4.2-2
- Add AppData file

* Sat Aug 24 2013 Jerry James <loganjerry@gmail.com> - 4.2-1
- New upstream release (fixes bz 972343)
- Fix eps2pdf BR (bz 913972 and 992196)
- Add BRs for newer versions of texlive
- Drop upstreamed -elisp patch
- Add upstream workaround for Emacs 24.3 byte-compilation error

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Jul 24 2012 Jerry James <loganjerry@gmail.com> - 4.1-1
- New upstream release
- Upstream no longer supports XEmacs
- Upstream no longer bundles X-Symbol
- Remove unnecessary spec file elements (defattr, etc.)
- Move desktop files into places where they will be used

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Jul 29 2009 Alan Dunn <amdunn@gmail.com> 3.7.1-4
- Incorporated comments from Jerry James about applying his patch:
  patch now applied unconditionally (regardless of Fedora version
  which was used as a somewhat imperfect way to control XEmacs
  version).
- Patch descriptions moved upward in spec file in accordance with
  examples in guidelines.

* Thu Jul 09 2009 Alan Dunn <amdunn@gmail.com> 3.7.1-3
- Added xemacs patch that fixes compilation problems for X-Symbol code.

* Thu Jul 02 2009 Alan Dunn <amdunn@gmail.com> 3.7.1-2
- Excluded bundled X-symbol, mmm-mode.
- Changed requires for these bundled packages.

* Tue Apr 07 2009 Alan Dunn <amdunn@gmail.com> 3.7.1-1
- Initial Fedora RPM.
